==> vtk6-6.3.0-4-armv6h.pkg.tar.xz: vtk/vtkTextSource.java <==
// java wrapper for vtkTextSource object
//

package vtk;
import vtk.*;

public class vtkTextSource extends vtkPolyDataAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetText_2(String id0);
  public void SetText(String id0)
    { SetText_2(id0); }

  private native String GetText_3();
  public String GetText()
    { return GetText_3(); }

  private native void SetBacking_4(int id0);
  public void SetBacking(int id0)
    { SetBacking_4(id0); }

  private native int GetBacking_5();
  public int GetBacking()
    { return GetBacking_5(); }

  private native void BackingOn_6();
  public void BackingOn()
    { BackingOn_6(); }

  private native void BackingOff_7();
  public void BackingOff()
    { BackingOff_7(); }

  private native void SetForegroundColor_8(double id0,double id1,double id2);
  public void SetForegroundColor(double id0,double id1,double id2)
    { SetForegroundColor_8(id0,id1,id2); }

  private native void SetForegroundColor_9(double id0[]);
  public void SetForegroundColor(double id0[])
    { SetForegroundColor_9(id0); }

  private native double[] GetForegroundColor_10();
  public double[] GetForegroundColor()
    { return GetForegroundColor_10(); }

  private native void SetBackgroundColor_11(double id0,double id1,double id2);
  public void SetBackgroundColor(double id0,double id1,double id2)
    { SetBackgroundColor_11(id0,id1,id2); }

  private native void SetBackgroundColor_12(double id0[]);
  public void SetBackgroundColor(double id0[])
    { SetBackgroundColor_12(id0); }

  private native double[] GetBackgroundColor_13();
  public double[] GetBackgroundColor()
    { return GetBackgroundColor_13(); }

  private native void SetOutputPointsPrecision_14(int id0);
  public void SetOutputPointsPrecision(int id0)
    { SetOutputPointsPrecision_14(id0); }

  private native int GetOutputPointsPrecision_15();
  public int GetOutputPointsPrecision()
    { return GetOutputPointsPrecision_15(); }

  public vtkTextSource() { super(); }

  public vtkTextSource(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-17-armv6h.pkg.tar.xz: vtk/vtkTextSource.java <==
// java wrapper for vtkTextSource object
//

package vtk;
import vtk.*;

public class vtkTextSource extends vtkPolyDataAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetText_2(String id0);
  public void SetText(String id0)
    { SetText_2(id0); }

  private native String GetText_3();
  public String GetText()
    { return GetText_3(); }

  private native void SetBacking_4(int id0);
  public void SetBacking(int id0)
    { SetBacking_4(id0); }

  private native int GetBacking_5();
  public int GetBacking()
    { return GetBacking_5(); }

  private native void BackingOn_6();
  public void BackingOn()
    { BackingOn_6(); }

  private native void BackingOff_7();
  public void BackingOff()
    { BackingOff_7(); }

  private native void SetForegroundColor_8(double id0,double id1,double id2);
  public void SetForegroundColor(double id0,double id1,double id2)
    { SetForegroundColor_8(id0,id1,id2); }

  private native void SetForegroundColor_9(double id0[]);
  public void SetForegroundColor(double id0[])
    { SetForegroundColor_9(id0); }

  private native double[] GetForegroundColor_10();
  public double[] GetForegroundColor()
    { return GetForegroundColor_10(); }

  private native void SetBackgroundColor_11(double id0,double id1,double id2);
  public void SetBackgroundColor(double id0,double id1,double id2)
    { SetBackgroundColor_11(id0,id1,id2); }

  private native void SetBackgroundColor_12(double id0[]);
  public void SetBackgroundColor(double id0[])
    { SetBackgroundColor_12(id0); }

  private native double[] GetBackgroundColor_13();
  public double[] GetBackgroundColor()
    { return GetBackgroundColor_13(); }

  private native void SetOutputPointsPrecision_14(int id0);
  public void SetOutputPointsPrecision(int id0)
    { SetOutputPointsPrecision_14(id0); }

  private native int GetOutputPointsPrecision_15();
  public int GetOutputPointsPrecision()
    { return GetOutputPointsPrecision_15(); }

  public vtkTextSource() { super(); }

  public vtkTextSource(long id) { super(id); }
  public native long   VTKInit();

}
